/*
 * Copyright 2021 Arne Vajhøj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.jnosql.bdbje;

import java.util.List;
import java.util.Map;
import java.util.Queue;
import java.util.Set;

import org.eclipse.jnosql.communication.keyvalue.BucketManager;
import org.eclipse.jnosql.communication.keyvalue.BucketManagerFactory;

import dk.vajhoej.jnosql.Deserialize;
import dk.vajhoej.jnosql.Serialize;

class BDBJEBucketManagerFactory implements BucketManagerFactory {
	private String dbdir;
	private String dbnam;
	private boolean prefix;
	private Serialize to;
	private Deserialize from;
	public BDBJEBucketManagerFactory(String dbdir, String dbnam, boolean prefix, Serialize to, Deserialize from) {
		this.dbdir = dbdir;
		this.dbnam = dbnam;
		this.prefix = prefix;
		this.to = to;
		this.from = from;
	}
	@Override
	public BucketManager apply(String bucket) {
		return new BDBJEBucketManager(dbdir, dbnam, prefix, bucket, to, from);
	}
	@Override
	public <T> List<T> getList(String name, Class<T> clz) {
		throw new UnsupportedOperationException("BDB-JE does not support List");
	}

	@Override
	public <K, V> Map<K, V> getMap(String name, Class<K> keyclz, Class<V> valclz) {
		throw new UnsupportedOperationException("BDB-JE does not support Map");
	}
	@Override
	public <T> Queue<T> getQueue(String name, Class<T> clz) {
		throw new UnsupportedOperationException("BDB-JE does not support Queue");
	}

	@Override
	public <T> Set<T> getSet(String name, Class<T> clz) {
		throw new UnsupportedOperationException("BDB-JE does not support Set");
	}
	@Override
	public void close() {
	}
}
